.. _linalg:

Linear algebra
**************

Tools of linear algebra.

Polynomials
-----------

.. autoclass:: sknetwork.linalg.Polynome

Sparse + Low Rank
-----------------

.. autoclass:: sknetwork.linalg.SparseLR

Operators
---------

.. autoclass:: sknetwork.linalg.Regularizer

.. autoclass:: sknetwork.linalg.Normalizer

.. autoclass:: sknetwork.linalg.Laplacian

.. autoclass:: sknetwork.linalg.CoNeighbor

Solvers
-------

.. autoclass:: sknetwork.linalg.LanczosEig

.. _lanczossvd:
.. autoclass:: sknetwork.linalg.LanczosSVD

.. autofunction:: sknetwork.linalg.ppr_solver.get_pagerank

Miscellaneous
-------------

.. autofunction:: sknetwork.linalg.diag_pinv

.. autofunction:: sknetwork.linalg.normalize
